import arcpy
import os
import numpy
import re
from arcpy import env
from arcpy.sa import *
import arcpy.cartography as CA

arcpy.CheckOutExtension('Spatial')
arcpy.overwriteOutput = True
env.qualifiedFieldNames = True
arcpy.env.addOutputsToMap = False

# Import Data
WorkspaceInterm = arcpy.GetParameterAsText(0) # Set default workspace (for intermediate steps) --> set folder 
Extent = arcpy.GetParameterAsText(1) # Extent polygon for Korea
Widmos = arcpy.GetParameterAsText(2) # Stream data presence
WorkspaceF = arcpy.GetParameterAsText(3) # Final workspace to save output from LMS
buf = arcpy.GetParameterAsText(4) # Buffer size
Country = arcpy.GetParameterAsText(5) # Country boundaries


#################################################
#### LMS
#################################################

# Clip to North Korean and South Korean Country Boundaries
env.workspace = WorkspaceInterm
ns = arcpy.management.SelectLayerByAttribute(Country, "NEW_SELECTION", "ISO = 'KR' Or ISO = 'KP'")
OutBuf_NS = "Country_Buf_NS.shp"
Country_Buf_NS = arcpy.analysis.Buffer(ns, OutBuf_NS, "25 Kilometers", "FULL", "ROUND")
s = arcpy.management.SelectLayerByAttribute(Country, "NEW_SELECTION", "ISO = 'KR'")
OutBuf_S = "Country_Buf_S.shp"
Country_Buf_S = arcpy.analysis.Buffer(s, OutBuf_S, "25 Kilometers", "FULL", "ROUND")

OutClip = "Extent_Clip.shp"
Extent2 = arcpy.analysis.Clip(Extent, Country_Buf_NS, OutClip)


# Project 
outCS = arcpy.SpatialReference('WGS 1984 UTM Zone 52N')
env.workspace = WorkspaceInterm
OutProj = "Proj.shp"
Proj = arcpy.Project_management(Extent2, OutProj, outCS)
# Minimum Bounding Geometry
arcpy.AddMessage('Minimum Bounding Geometry')
env.workspace = WorkspaceInterm
OutInterm = "BoundGeom.shp"
BoundGeom = arcpy.MinimumBoundingGeometry_management(Proj, OutInterm, "CONVEX_HULL", "NONE")

# Erase 
arcpy.AddMessage('Erase')
BoundGeom_Erase = arcpy.Erase_analysis(BoundGeom, Proj, "BoundGeom_Erase.shp")

# Eliminate Polygon Part
arcpy.AddMessage('Eliminate Polygon Part')
EPP_LMS = arcpy.management.EliminatePolygonPart(BoundGeom_Erase, "EPP_LMS.shp", "AREA", 8100000)

# Multipart to Singlepart
arcpy.AddMessage('Multipart to Singlepart')
EPP_LMS_MultipartToSinglepart = arcpy.MultipartToSinglepart_management(EPP_LMS, "EPP_LMS_MultipartToSinglepart.shp")

# Reclassify
arcpy.AddMessage('Reclassify')
MERIT_Reclass = Reclassify(Widmos, "VALUE", RemapRange([[-1,0,1],[0,15944.0625,2],["NODATA","NODATA",1]]))

# Zonal Statistics as Table
arcpy.AddMessage('Zonal Statistics as Table')
ZonalSt_EPP_LMS = ZonalStatisticsAsTable(EPP_LMS_MultipartToSinglepart, "FID", MERIT_Reclass, "ZONALSt_EPP_LMS", "DATA", "MAXIMUM")

# Join Field
arcpy.AddMessage('Join Field')
arcpy.JoinField_management(EPP_LMS_MultipartToSinglepart,"FID", ZonalSt_EPP_LMS, "FID")

# Select
arcpy.AddMessage('Select')
RivPres_Slct = arcpy.Select_analysis(EPP_LMS_MultipartToSinglepart, "RivPres_Slct.shp", '"MAX" = 2')

# Copy Features
arcpy.AddMessage('Copy Features')
riv_select = arcpy.CopyFeatures_management(RivPres_Slct, "riv_select.shp")

# Dissolve
arcpy.AddMessage('Dissolve')
riv_select_dissolve = arcpy.Dissolve_management(riv_select, "riv_select_dissolve.shp", "", "", "SINGLE_PART")

# Multipart to Singlepart
arcpy.AddMessage('Multipart to Singlepart')
riv_sel_union_MtoS = arcpy.MultipartToSinglepart_management(riv_select_dissolve, "riv_sel_union_MtoS.shp")

# Attribute Table
arcpy.AddMessage('Attribute Table')
arcpy.management.AddField(riv_sel_union_MtoS, "Area_M", "FLOAT", "", "", "", "NULLABLE")
arcpy.management.AddField(riv_sel_union_MtoS, "Area_KM", "FLOAT", "", "", "", "NULLABLE")
arcpy.CalculateField_management(riv_sel_union_MtoS, "Area_M", '!shape.area!', 'PYTHON')
expression = '!Area_M!/1000000'
arcpy.CalculateField_management(riv_sel_union_MtoS, "Area_KM", expression, 'PYTHON')
LMS_sorter = arcpy.management.Sort(riv_sel_union_MtoS, "LMS_sorter.shp", [["AREA_KM", "DESCENDING"]])
arcpy.management.AddField(LMS_sorter, "AreaKMord", "SHORT", "", "", "", "NULLABLE")
expression = 'autoIncrement(!Area_KM!)'
codeblock = """
rec=0 
def autoIncrement(self): 
	global rec 
	pStart = 1  
	pInterval = 1 
	if (rec == 0):  
		rec = pStart  
	else:  
		rec += pInterval  
	return rec"""
arcpy.CalculateField_management(LMS_sorter, "AreaKMord", str(expression), "PYTHON", codeblock)
Fin = arcpy.analysis.Select(LMS_sorter, "Fin.shp", '"AreaKMord" = 1')
copy_name = 'Fin.shp'
copy_name2 = 'Fin_cop.shp'
copy_output = os.path.join(WorkspaceInterm, copy_name2)
copy_input = os.path.join(WorkspaceInterm, copy_name)
arcpy.management.CopyFeatures(copy_input, copy_output)
#arcpy.analysis.SplitByAttributes(LMS_sorter, WorkspaceInterm, "AreaKMord")


#################################################
#### CFID
#################################################


# Iterate through land masses
InLM_proj = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_cop.shp'):
			InLM_proj.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

# Simplify polygon
suffix = 'simpPoly'
for fc in InLM_proj:
	simp_name = arcpy.Describe(fc).baseName + '_' + suffix
	simp_output = os.path.join(WorkspaceInterm, simp_name)
	if (os.path.exists(simp_output)):
		print('Already exists')
	else:
		LM_simp = arcpy.SimplifyPolygon_cartography(fc, simp_output, "POINT_REMOVE", 1000, "", "", "NO_KEEP") 
		arcpy.Delete_management("in_memory")

# Buffer
InLM_simp = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_simpPoly.shp'):
			InLM_simp.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'buf250km'
for fc in InLM_simp:
	buf_name = arcpy.Describe(fc).baseName + '_' + suffix
	buf_output = os.path.join(WorkspaceInterm, buf_name)
	LM_buf = arcpy.analysis.Buffer(fc, buf_output, 700000, "FULL", "ROUND", "NONE", "", "PLANAR")
	arcpy.Delete_management("in_memory")

suffix = 'buf15km'
for fc in InLM_simp:
	buf_name = arcpy.Describe(fc).baseName + '_' + suffix
	buf_output = os.path.join(WorkspaceInterm, buf_name)
	LM_buf = arcpy.analysis.Buffer(fc, buf_output, 75000, "FULL", "ROUND", "NONE", "", "PLANAR")
	arcpy.Delete_management("in_memory")

# Erase
InLM_buf250 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_buf250km.shp'):
			InLM_buf250.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

InLM_buf15 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_buf15km.shp'):
			InLM_buf15.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'erase'
for fc in InLM_buf250:
	for fc2 in InLM_proj:
		aa = fc.split('_')
		bb = fc2.split('_')
		if aa[0] == bb[0]:
			era_name = arcpy.Describe(fc2).baseName + '_' + suffix
			era_output = os.path.join(WorkspaceInterm, era_name)
			arcpy.Erase_analysis(fc, fc2, era_output)
			arcpy.Delete_management("in_memory")
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))
				

# Simplify polygon
InLM_era = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_erase.shp'):
			InLM_era.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'simpPoly2'
for fc in InLM_era:
	simp_name = arcpy.Describe(fc).baseName + '_' + suffix
	simp_output = os.path.join(WorkspaceInterm, simp_name)
	LM_simp = arcpy.SimplifyPolygon_cartography(fc, simp_output, "POINT_REMOVE", 30, "", "", "NO_KEEP") 
	arcpy.Delete_management("in_memory")


#Eliminate polygon part
InLM_sim = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_erase_simpPoly2.shp'):
			InLM_sim.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'eli'
for fc in InLM_sim:
	eli_name = arcpy.Describe(fc).baseName + '_' + suffix
	eli_output = os.path.join(WorkspaceInterm, eli_name)
	LM_eli = arcpy.management.EliminatePolygonPart(fc, eli_output, "AREA", 50000000)
	arcpy.Delete_management("in_memory")


# Large Negative buffer
InLM_eli = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_erase_simpPoly2_eli.shp'):
			InLM_eli.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'buf_neg'
for fc in InLM_eli:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_')    
	buf_name = bbb[0] + '_' + suffix
	buf_output = os.path.join(WorkspaceInterm, buf_name)
	LM_buf = arcpy.analysis.Buffer(fc, buf_output, '-' + buf, "FULL", "ROUND", "NONE")
	arcpy.Delete_management("in_memory")


# Eliminate polygon part
InLM_buf = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_buf_neg.shp'):
			InLM_buf.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))


suffix = 'eli2'
for fc in InLM_buf:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	eli2_name = bbb[0] + '_' + suffix
	eli2_output = os.path.join(WorkspaceInterm, eli2_name)
	LM_eli = arcpy.management.EliminatePolygonPart(fc, eli2_output, "PERCENT", 0.05)
	arcpy.Delete_management("in_memory")


# Large positive buffer
InLM_eli2 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_eli2.shp'):
			InLM_eli2.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'buf_pos'
for fc in InLM_eli2:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	buf_name = bbb[0] + '_' + suffix
	buf_output = os.path.join(WorkspaceInterm, buf_name)
	LM_buf = arcpy.analysis.Buffer(fc, buf_output, buf, "FULL", "ROUND", "NONE")
	arcpy.Delete_management("in_memory")


# Erase buffers
suffix = 'eraera'
for fc in InLM_buf250:
	for fc2 in InLM_buf15:
		aaa1 = re.split(r"[\b\W\b]+", fc) 
		aaa2 = aaa1[-2].split('_') 
		bbb1 = re.split(r"[\b\W\b]+", fc2) 
		bbb2 = bbb1[-2].split('_') 
		if aaa2[0] == bbb2[0]:	
			era_name = aaa2[0] + '_' + suffix
			era_output = os.path.join(WorkspaceInterm, era_name)
			arcpy.Erase_analysis(fc, fc2, era_output)
			arcpy.Delete_management("in_memory")
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))


# 150m buffer (artifact remover)
InLM_eraera = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_eraera.shp'):
			InLM_eraera.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'buf_arti'
for fc in InLM_eraera:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	buf_name = bbb[0] + '_' + suffix
	buf_output = os.path.join(WorkspaceInterm, buf_name)
	LM_buf = arcpy.analysis.Buffer(fc, buf_output, "150 Meters", "FULL", "ROUND", "NONE")
	arcpy.Delete_management("in_memory")

# Union
InLM_bufpos = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_buf_pos.shp'):
			InLM_bufpos.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

InLM_buf150 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_buf_arti.shp'):
			InLM_buf150.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'union'
for fc in InLM_bufpos:
	for fc2 in InLM_buf150:
		aaa1 = re.split(r"[\b\W\b]+", fc) 
		aaa2 = aaa1[-2].split('_') 
		bbb1 = re.split(r"[\b\W\b]+", fc2) 
		bbb2 = bbb1[-2].split('_') 
		if aaa2[0] == bbb2[0]:	
			uni_name = aaa2[0] + '_' + suffix
			uni_output = os.path.join(WorkspaceInterm, uni_name)
			arcpy.Union_analysis([fc2, fc], uni_output, "ALL", "", "GAPS")
			arcpy.Delete_management("in_memory")
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

InLM_union = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_union.shp'):
			InLM_union.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

# Dissolve
suffix = "diss"
for fc in InLM_union:
	arcpy.management.AddField(fc, "Arti_Diss", "SHORT", "", "", "", "NULLABLE")
	arcpy.CalculateField_management(fc, "Arti_Diss", '1', 'PYTHON')
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	dis_name = bbb[0] + '_' + suffix
	dis_output = os.path.join(WorkspaceInterm, dis_name)
	LM_dis = arcpy.management.Dissolve(fc, dis_output, "Arti_Diss", "", "MULTI_PART", "DISSOLVE_LINES")
	arcpy.Delete_management("in_memory")

# Copy 
InLM_diss = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_diss.shp'):
			InLM_diss.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = "copy"
for fc in InLM_diss:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	copy_name = bbb[0] + '_' + suffix
	copy_output = os.path.join(WorkspaceInterm, copy_name)
	LM_copy = arcpy.CopyFeatures_management(fc, copy_output)
	arcpy.Delete_management("in_memory")
	
suffix = "copy2"
for fc in InLM_eli:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	copy2_name = bbb[0] + '_' + suffix
	copy2_output = os.path.join(WorkspaceInterm, copy2_name)
	LM_copy2 = arcpy.CopyFeatures_management(fc, copy2_output)
	arcpy.Delete_management("in_memory")

# Dissolve
InLM_copy = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_copy.shp'):
			InLM_copy.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

InLM_copy2 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_copy2.shp'):
			InLM_copy2.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = "diss2"
for fc in InLM_copy2:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	diss2_name = bbb[0] + '_' + suffix
	diss2_output = os.path.join(WorkspaceInterm, diss2_name)
	LM_diss2 = arcpy.management.Dissolve(fc, diss2_output, "", "", "MULTI_PART", "DISSOLVE_LINES")
	arcpy.Delete_management("in_memory")

# Erase
InLM_diss2 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_diss2.shp'):
			InLM_diss2.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'erase2'
for fc in InLM_diss2:
	for fc2 in InLM_copy:
		aaa1 = re.split(r"[\b\W\b]+", fc) 
		aaa2 = aaa1[-2].split('_') 
		bbb1 = re.split(r"[\b\W\b]+", fc2) 
		bbb2 = bbb1[-2].split('_') 
		if aaa2[0] == bbb2[0]:	
			era_name = aaa2[0] + '_' + suffix
			era_output = os.path.join(WorkspaceInterm, era_name)
			arcpy.Erase_analysis(fc, fc2, era_output)
			arcpy.Delete_management("in_memory")
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

#Multipart to Singlepart
InLM_erase2 = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_erase2.shp'):
			InLM_erase2.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = 'singmulti'
for fc in InLM_erase2:
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	singmulti_name = bbb[0] + '_' + suffix
	singmulti_output = os.path.join(WorkspaceInterm, singmulti_name)
	LM_singmulti = arcpy.MultipartToSinglepart_management(fc, singmulti_output)
	arcpy.Delete_management("in_memory")


#Add Field
InLM_singmulti = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_singmulti.shp'):
			InLM_singmulti.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

#Sort
suffix = 'sort'
for fc in InLM_singmulti:
	arcpy.management.AddField(fc, "Area_KM", "FLOAT", "", "", "", "NULLABLE")
	arcpy.management.CalculateGeometryAttributes(fc, [["Area_KM", "AREA"]], "", "SQUARE_KILOMETERS")
	aaa = re.split(r"[\b\W\b]+", fc) 
	bbb = aaa[-2].split('_') 
	sort_name = bbb[0] + '_' + suffix
	sort_output = os.path.join(WorkspaceInterm, sort_name)
	LM_sort = arcpy.management.Sort(fc, sort_output, [["Area_KM", "DESCENDING"]])
	arcpy.Delete_management("in_memory")


#Add Field
InLM_sort = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_sort.shp'):
			InLM_sort.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

expression = 'autoIncrement(!Area_KM!)'
codeblock = """
rec=0 
def autoIncrement(self): 
	global rec 
	pStart = 1  
	pInterval = 1 
	if (rec == 0):  
		rec = pStart  
	else:  
		rec += pInterval  
	return rec"""


list = []
k = 0

for fc in InLM_sort:
	arcpy.management.AddField(fc, "AreaKMord", "SHORT", "", "", "", "NULLABLE")
	arcpy.CalculateField_management(fc, "AreaKMord", str(expression), "PYTHON", codeblock)
	arcpy.management.AddField(fc, "ID_LM_EMB", "TEXT", "", "", "", "NULLABLE")
	SC = arcpy.SearchCursor(fc)
	field_name = 'AreaKMord'
	field_name2 = 'ID_LM_EMB'
	for row in SC:
		mm = row.getValue(field_name)
		list.append(mm)
		k += 1
	k = 1
	with arcpy.da.UpdateCursor(fc,field_name2) as rows:
		for row in rows:
			row[0] = "Fin" + '_' + str(k)
			k += 1 
			rows.updateRow(row)
	arcpy.conversion.FeatureClassToShapefile(fc, WorkspaceInterm)



#################################################
#### CSWCP
#################################################


FinalEmb = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_sort_1.shp'):
			FinalEmb.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = "RecW_removal"
for fc in FinalEmb:
	arcpy.DeleteField_management(fc, ["Area_KM", "Shape_Leng", "Shape_Area"])
	arcpy.management.AddField(fc, "AREA_Msq", "FLOAT", "", "", "", "NULLABLE")
	arcpy.management.CalculateGeometryAttributes(fc, [["Area_Msq", "AREA"]], "", "SQUARE_METERS")
	bound_name = arcpy.Describe(fc).baseName + '_' + suffix
	bound_output = os.path.join(WorkspaceInterm, bound_name)
	Bound = arcpy.management.MinimumBoundingGeometry(fc, bound_output, "RECTANGLE_BY_WIDTH", "NONE", "", "MBG_FIELDS")
	arcpy.Delete_management("in_memory")
	
Remov = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_RecW_removal.shp'):
			Remov.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

suffix = "Select"
where_clause = '"AREA_Msq" > 8100 OR "MBG_Width" > 90'
for fc in Remov:
	for fc2 in FinalEmb:
		aaa1 = re.split(r"[\b\W\b]+", fc) 
		aaa2 = aaa1[-2].split('_') 
		bbb1 = re.split(r"[\b\W\b]+", fc2) 
		bbb2 = bbb1[-2].split('_') 
		if aaa2[0] == bbb2[0]:
			arcpy.management.JoinField(fc2, "ID_LM_EMB", fc, "ID_LM_EMB")
			sel_name = aaa2[0] + '_' + suffix
			sel_output = os.path.join(WorkspaceInterm, sel_name)
			arcpy.analysis.Select(fc2, sel_output, where_clause)
			arcpy.Delete_management("in_memory")			
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

Sel = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		if filename.endswith('_Select.shp'):
			Sel.append(os.path.join(dirpath, filename))
		else:
			arcpy.AddMessage('Skip appending {0}'.format(filename))

ccc = re.split(r"[\b\W\b]+", buf)
suffix = 'Final' + '_' + str(ccc[0])
for fc in Sel:
	rmvd_name = suffix
	rmvd_output = os.path.join(WorkspaceF, rmvd_name)
	arcpy.analysis.Clip(fc, Country_Buf_S, rmvd_output)
	arcpy.Delete_management("in_memory")

env.workspace = WorkspaceInterm
r_list = ListRasters()
s_list = []
for dirpath, dirnames, filenames in arcpy.da.Walk(WorkspaceInterm, topdown = True, datatype = 'FeatureClass', type = 'Polygon'):
	for filename in filenames:
		s_list.append(os.path.join(dirpath, filename))

arcpy.Delete_management(r_list); arcpy.Delete_management(s_list)









	

